@@ -33,7 +33,7 @@ pub use nettu_scheduler_domain::{
 pub use schedule::{CreateScheduleInput, UpdateScheduleInput};
 pub use service::{
     AddServiceUserInput, CreateBookingIntendInput, CreateServiceInput, GetServiceBookingSlotsInput,
-    RemoveServiceUserInput, UpdateServiceUserInput,
+    RemoveServiceUserInput, UpdateServiceInput, UpdateServiceUserInput,
 };
 pub use shared::{KVMetadata, MetadataFindInput};
 pub use user::CreateUserInput;
